searchData={"items":[{"type":"module","doc":"This module is used to manipulate bitwise flags.\n\n  Inspired by: [Flags in C#](https://stackoverflow.com/questions/8447/what-does-the-flags-enum-attribute-mean-in-c)\n\n  Event sourced systems often rely on flags to indicate the state of the aggregate at any given time.\n  In essence, an event sourced aggregate is a finite state machine and this state is \n  often represented as a set of flags, to be used as a shorthand for the state of the aggregate.\n\n  In this module, we define a set of functions that can be used to manipulate these flags.","title":"BeamCampus.BitFlags","ref":"BeamCampus.BitFlags.html"},{"type":"function","doc":"","title":"BeamCampus.BitFlags.decompose/1","ref":"BeamCampus.BitFlags.html#decompose/1"},{"type":"function","doc":"Returs true if the given flag is set in the target state.\n  In other words, it returns true if the bit that corresponds to the flag is set.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flag to be checked is `0b01000000` (integer: 64)\n  THEN the result is `true`\n\n  Example:\n  iex> BitFlags.has?(100, 64)\n  true","title":"BeamCampus.BitFlags.has?/2","ref":"BeamCampus.BitFlags.html#has?/2"},{"type":"function","doc":"Returns true if ALL the flags are set in the target state.\n  In other words, it returns true if ALL the bits that correspond to the flags are set.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flags to be checked are `[0b01000000, 0b10000000]` (integers: 64, 128)\n  THEN the result is `true`\n  AND WHEN the flags to be checked are `[0b01000000, 0b00000100]` (integers: 64, 8)\n  THEN the result is `false`\n\n  Example:\n  iex> BitFlags.has_all?(100, [64, 128])\n  true\n  iex> BitFlags.has_all?(100, [64, 8])\n  false","title":"BeamCampus.BitFlags.has_all?/2","ref":"BeamCampus.BitFlags.html#has_all?/2"},{"type":"function","doc":"Returns true if any of the flags are set in the target state.\n  In other words, it returns true if any of the bits that correspond to the flags are set.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flags to be checked are `[0b01000000, 0b10000000]` (integers: 64, 128)\n  THEN the result is `true`\n\n  Example:\n  iex> BitFlags.has_any?(100, [64, 128])\n  true","title":"BeamCampus.BitFlags.has_any?/2","ref":"BeamCampus.BitFlags.html#has_any?/2"},{"type":"function","doc":"Returns true if the given flag is NOT set in the target state.\n  In other words, it returns true if the bit that corresponds to the flag is NOT set.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flag to be checked is `0b01000000` (integer: 64)\n  THEN the result is `false`\n  AND WHEN the flag to be checked is `0b00000100` (integer: 8)\n  THEN the result is `true`\n\n  Example:\n  iex> BitFlags.has_not?(100, 64)\n  false\n  iex> BitFlags.has_not?(100, 8)\n  true","title":"BeamCampus.BitFlags.has_not?/2","ref":"BeamCampus.BitFlags.html#has_not?/2"},{"type":"function","doc":"Returns the highest flag in the target state.\n  GIVEN: target_state is `0b01100100` (integer: 100)    \n  AND the flag_map is:\n      %{\n         0 => \"None\",\n         1 => \"Ready\",\n         2 => \"In Progress\",\n         4 => \"Completed\",\n         8 => \"Cancelled\",\n         16 => \"Failed\",\n         32 => \"Archived\",\n         64 => \"Ready to Archive\",\n         128 => \"Ready to Publish\",\n      }\n  THEN the result is `Ready to Archive`\n\n  Example:\n  iex> descriptions = \n  ...>  %{\n  ...>       0 => \"None\",\n  ...>       1 => \"Ready\",\n  ...>       2 => \"In Progress\",\n  ...>       4 => \"Completed\",\n  ...>       8 => \"Cancelled\",\n  ...>       16 => \"Failed\",\n  ...>       32 => \"Archived\",\n  ...>       64 => \"Ready to Archive\",\n  ...>       128 => \"Ready to Publish\",\n  ...>  }\n  %{\n     0 => \"None\",\n     1 => \"Ready\",\n     2 => \"In Progress\",\n     4 => \"Completed\",\n     8 => \"Cancelled\",\n     16 => \"Failed\",\n     32 => \"Archived\",\n     64 => \"Ready to Archive\",\n     128 => \"Ready to Publish\",\n  }\n  iex> BitFlags.highest(100, descriptions)\n  \"Ready to Archive\"","title":"BeamCampus.BitFlags.highest/2","ref":"BeamCampus.BitFlags.html#highest/2"},{"type":"function","doc":"Returns the lowest flag in the bit flag map.\n  GIVEN: target_state is `0b01100100` (integer: 100)\n  AND the flag_map is:\n      %{\n         0 => \"None\",\n         1 => \"Ready\",\n         2 => \"In Progress\",\n         4 => \"Completed\",\n         8 => \"Cancelled\",\n         16 => \"Failed\",\n         32 => \"Archived\",\n         64 => \"Ready to Archive\",\n         128 => \"Ready to Publish\",\n      }\n   THEN the result is `Ready`\n\n  Example:\n  iex> descriptions = \n  ...>  %{\n  ...>       0 => \"None\",\n  ...>       1 => \"Ready\",\n  ...>       2 => \"In Progress\",\n  ...>       4 => \"Completed\",\n  ...>       8 => \"Cancelled\",\n  ...>       16 => \"Failed\",\n  ...>       32 => \"Archived\",\n  ...>       64 => \"Ready to Archive\",\n  ...>       128 => \"Ready to Publish\",\n  ...>  }\n  %{\n     0 => \"None\",\n     1 => \"Ready\",\n     2 => \"In Progress\",\n     4 => \"Completed\",\n     8 => \"Cancelled\",\n     16 => \"Failed\",\n     32 => \"Archived\",\n     64 => \"Ready to Archive\",\n     128 => \"Ready to Publish\",\n  }\n  iex> BitFlags.lowest(100, descriptions)\n  \"Ready\"","title":"BeamCampus.BitFlags.lowest/2","ref":"BeamCampus.BitFlags.html#lowest/2"},{"type":"function","doc":"Returns the bitwise OR of two flags.\n  In other words, it sets the bit that corresopnds to the flag\n  GIVEN: original_state is `0b00100100` (integer: 36) \n  WHEN the flag to be set is `0b01000000` (integer: 64)\n  THEN the result is `0b01100100` (integer: 100)\n\n  Example:\n  iex> BitFlags.set(36, 64)\n  100","title":"BeamCampus.BitFlags.set/2","ref":"BeamCampus.BitFlags.html#set/2"},{"type":"function","doc":"Returns the bitwise OR of multiple flags against a given state.\n  In other words, it sets the bits that corresopnds to the flags\n  GIVEN: original_state is `0b00100100` (integer: 36)\n  WHEN the flags to be set are `[0b01000000, 0b10000000]` (integers: 64, 128)\n  THEN the result is `0b11100100` (integer: 228)\n\n  Example:\n  iex> BitFlags.set_all(36, [64, 128])\n  228","title":"BeamCampus.BitFlags.set_all/2","ref":"BeamCampus.BitFlags.html#set_all/2"},{"type":"function","doc":"Returns a list of flag descriptions that are set in the target state.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  AND the flag_map is:\n     %{\n        0 => \"None\",\n        1 => \"Ready\",\n        2 => \"In Progress\",\n        4 => \"Completed\",\n        8 => \"Cancelled\",\n        16 => \"Failed\",\n        32 => \"Archived\",\n        64 => \"Ready to Archive\",\n        128 => \"Ready to Publish\",\n        256 => \"Published\",\n        512 => \"Unpublished\",\n     }\n  WHEN the target state is `0b01100100` (integer: 100)\n  THEN the result is `[\"Completed\", \"Archived\", \"Ready to Archive\"]`\n\n  Example: \n  iex> descriptions = \n  ...>  %{\n  ...>       0 => \"None\",\n  ...>       1 => \"Ready\",\n  ...>       2 => \"In Progress\",\n  ...>       4 => \"Completed\",\n  ...>       8 => \"Cancelled\",\n  ...>       16 => \"Failed\",\n  ...>       32 => \"Archived\",\n  ...>       64 => \"Ready to Archive\",\n  ...>       128 => \"Ready to Publish\",\n  ...>       256 => \"Published\",\n  ...>       512 => \"Unpublished\",\n  ...>  }\n  iex> BitFlags.to_list(100, descriptions)\n  [\"Completed\", \"Archived\", \"Ready to Archive\"]","title":"BeamCampus.BitFlags.to_list/2","ref":"BeamCampus.BitFlags.html#to_list/2"},{"type":"function","doc":"Returns a string representation of the bit flags.\n  GIVEN: target_state is `0b01100100` (integer: 100)\n  AND the flag_map is:\n       %{\n         0 => \"None\",\n         1 => \"Ready\",\n         2 => \"In Progress\",\n         4 => \"Completed\",\n         8 => \"Cancelled\",\n         16 => \"Failed\",\n         32 => \"Archived\",\n         64 => \"Ready to Archive\",\n         128 => \"Ready to Publish\",\n      }\n  THEN the result is `\"Completed, Archived, Ready to Archive\"`\n\n  Example:\n  iex> descriptions =\n  ...>  %{\n  ...>       0 => \"None\",\n  ...>       1 => \"Ready\",\n  ...>       2 => \"In Progress\",\n  ...>       4 => \"Completed\",\n  ...>       8 => \"Cancelled\",\n  ...>       16 => \"Failed\",\n  ...>       32 => \"Archived\",\n  ...>       64 => \"Ready to Archive\",\n  ...>       128 => \"Ready to Publish\",\n  ...>  }\n  iex> BitFlags.to_string(100, descriptions)\n  \"Completed, Archived, Ready to Archive\"","title":"BeamCampus.BitFlags.to_string/2","ref":"BeamCampus.BitFlags.html#to_string/2"},{"type":"function","doc":"","title":"BeamCampus.BitFlags.toggle/2","ref":"BeamCampus.BitFlags.html#toggle/2"},{"type":"function","doc":"","title":"BeamCampus.BitFlags.toggle_all/2","ref":"BeamCampus.BitFlags.html#toggle_all/2"},{"type":"function","doc":"Returns the bitwise AND of two flags.\n  In other words, it unsets the bit that corresopnds to the flag\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flag to be unset is `0b01000000` (integer: 64)\n  THEN the result is `0b00100100` (integer: 36)\n\n  Example:\n  iex> BitFlags.unset(100, 64)\n  36","title":"BeamCampus.BitFlags.unset/2","ref":"BeamCampus.BitFlags.html#unset/2"},{"type":"function","doc":"Returns the bitwise AND of multiple flags against a given state.\n  In other words, it unsets the bits that corresopnds to the flags\n  GIVEN: original_state is `0b11100100` (integer: 228)\n  WHEN the flags to be unset are `[0b01000000, 0b10000000]` (integers: 64, 128)\n  THEN the result is `0b00100100` (integer: 36)\n\n  Example:\n  iex> BitFlags.unset_all(228, [64, 128])\n  36","title":"BeamCampus.BitFlags.unset_all/2","ref":"BeamCampus.BitFlags.html#unset_all/2"},{"type":"module","doc":"This module is used to manipulate colors.\n  It offers a set of functions that can be used to \n  change the color of text in the terminal, using ANSI escape codes.\n  It covers all color combinations and effects supported by ANSI.","title":"BeamCampus.ColorFuncs","ref":"BeamCampus.ColorFuncs.html"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_black/0","ref":"BeamCampus.ColorFuncs.html#black_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_blue/0","ref":"BeamCampus.ColorFuncs.html#black_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#black_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#black_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#black_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#black_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#black_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#black_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#black_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#black_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#black_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_green/0","ref":"BeamCampus.ColorFuncs.html#black_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#black_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_red/0","ref":"BeamCampus.ColorFuncs.html#black_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_white/0","ref":"BeamCampus.ColorFuncs.html#black_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.black_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#black_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_black/0","ref":"BeamCampus.ColorFuncs.html#blue_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_blue/0","ref":"BeamCampus.ColorFuncs.html#blue_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#blue_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_green/0","ref":"BeamCampus.ColorFuncs.html#blue_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#blue_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_red/0","ref":"BeamCampus.ColorFuncs.html#blue_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_white/0","ref":"BeamCampus.ColorFuncs.html#blue_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.blue_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#blue_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_black/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_green/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_red/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_white/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_black_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_black_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_black/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_green/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_red/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_white/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_blue_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_black/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_green/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_red/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_white/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_cyan_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_black/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_green/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_red/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_white/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_green_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_green_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_black/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_green/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_red/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_white/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_magenta_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_black/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_green/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_red/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_white/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_red_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_red_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_black/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_green/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_red/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_white/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_white_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_white_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_black/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_green/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_red/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_white/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.bright_yellow_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_black/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_blue/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_green/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_red/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_white/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.cyan_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#cyan_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_black/0","ref":"BeamCampus.ColorFuncs.html#green_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_blue/0","ref":"BeamCampus.ColorFuncs.html#green_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#green_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#green_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#green_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#green_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#green_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#green_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#green_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#green_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#green_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_green/0","ref":"BeamCampus.ColorFuncs.html#green_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#green_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_red/0","ref":"BeamCampus.ColorFuncs.html#green_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_white/0","ref":"BeamCampus.ColorFuncs.html#green_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.green_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#green_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_black/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_blue/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_green/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_red/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_white/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.magenta_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#magenta_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_black/0","ref":"BeamCampus.ColorFuncs.html#red_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_blue/0","ref":"BeamCampus.ColorFuncs.html#red_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#red_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#red_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#red_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#red_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#red_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#red_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#red_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#red_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#red_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_green/0","ref":"BeamCampus.ColorFuncs.html#red_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#red_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_red/0","ref":"BeamCampus.ColorFuncs.html#red_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_white/0","ref":"BeamCampus.ColorFuncs.html#red_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.red_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#red_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.reset/0","ref":"BeamCampus.ColorFuncs.html#reset/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.tui/3","ref":"BeamCampus.ColorFuncs.html#tui/3"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_black/0","ref":"BeamCampus.ColorFuncs.html#white_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_blue/0","ref":"BeamCampus.ColorFuncs.html#white_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#white_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#white_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#white_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#white_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#white_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#white_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#white_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#white_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#white_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_green/0","ref":"BeamCampus.ColorFuncs.html#white_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#white_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_red/0","ref":"BeamCampus.ColorFuncs.html#white_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_white/0","ref":"BeamCampus.ColorFuncs.html#white_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.white_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#white_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_black/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_blue/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_bright_black/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_black/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_bright_blue/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_blue/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_bright_cyan/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_bright_green/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_bright_magenta/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_bright_red/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_bright_white/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_bright_yellow/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_cyan/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_green/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_magenta/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_red/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_white/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.ColorFuncs.yellow_on_yellow/0","ref":"BeamCampus.ColorFuncs.html#yellow_on_yellow/0"},{"type":"module","doc":"This module is used to manipulate colors.\n  It offers a set of functions that can be used to \n  change the color of text in the terminal, using ANSI escape codes.","title":"BeamCampus.Colors","ref":"BeamCampus.Colors.html"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_black/0","ref":"BeamCampus.Colors.html#black_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_blue/0","ref":"BeamCampus.Colors.html#black_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_blue_blinking/0","ref":"BeamCampus.Colors.html#black_on_blue_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_cyan/0","ref":"BeamCampus.Colors.html#black_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_cyan_blinking/0","ref":"BeamCampus.Colors.html#black_on_cyan_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_green/0","ref":"BeamCampus.Colors.html#black_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_green_blinking/0","ref":"BeamCampus.Colors.html#black_on_green_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_magenta/0","ref":"BeamCampus.Colors.html#black_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_magenta_blinking/0","ref":"BeamCampus.Colors.html#black_on_magenta_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_red/0","ref":"BeamCampus.Colors.html#black_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_red_blinking/0","ref":"BeamCampus.Colors.html#black_on_red_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_white/0","ref":"BeamCampus.Colors.html#black_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_white_blinking/0","ref":"BeamCampus.Colors.html#black_on_white_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_yellow/0","ref":"BeamCampus.Colors.html#black_on_yellow/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.black_on_yellow_blinking/0","ref":"BeamCampus.Colors.html#black_on_yellow_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.blue_on_black/0","ref":"BeamCampus.Colors.html#blue_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.blue_on_black_blinking/0","ref":"BeamCampus.Colors.html#blue_on_black_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.blue_on_white/0","ref":"BeamCampus.Colors.html#blue_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.cyan_on_black/0","ref":"BeamCampus.Colors.html#cyan_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.cyan_on_black_blinking/0","ref":"BeamCampus.Colors.html#cyan_on_black_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.cyan_on_white/0","ref":"BeamCampus.Colors.html#cyan_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.green_on_black/0","ref":"BeamCampus.Colors.html#green_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.green_on_black_blinking/0","ref":"BeamCampus.Colors.html#green_on_black_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.green_on_white/0","ref":"BeamCampus.Colors.html#green_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.grey_on_black/0","ref":"BeamCampus.Colors.html#grey_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.magenta_on_black/0","ref":"BeamCampus.Colors.html#magenta_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.magenta_on_black_blinking/0","ref":"BeamCampus.Colors.html#magenta_on_black_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.magenta_on_white/0","ref":"BeamCampus.Colors.html#magenta_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.orange_on_black/0","ref":"BeamCampus.Colors.html#orange_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.red_on_black/0","ref":"BeamCampus.Colors.html#red_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.red_on_black_blinking/0","ref":"BeamCampus.Colors.html#red_on_black_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.red_on_white/0","ref":"BeamCampus.Colors.html#red_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.reset/0","ref":"BeamCampus.Colors.html#reset/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.white_on_black/0","ref":"BeamCampus.Colors.html#white_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.white_on_black_blinking/0","ref":"BeamCampus.Colors.html#white_on_black_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.white_on_blue/0","ref":"BeamCampus.Colors.html#white_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.white_on_cyan/0","ref":"BeamCampus.Colors.html#white_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.white_on_green/0","ref":"BeamCampus.Colors.html#white_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.white_on_magenta/0","ref":"BeamCampus.Colors.html#white_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.white_on_red/0","ref":"BeamCampus.Colors.html#white_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.white_on_white/0","ref":"BeamCampus.Colors.html#white_on_white/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_black/0","ref":"BeamCampus.Colors.html#yellow_on_black/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_black_blinking/0","ref":"BeamCampus.Colors.html#yellow_on_black_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_blue/0","ref":"BeamCampus.Colors.html#yellow_on_blue/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_blue_blinking/0","ref":"BeamCampus.Colors.html#yellow_on_blue_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_cyan/0","ref":"BeamCampus.Colors.html#yellow_on_cyan/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_cyan_blinking/0","ref":"BeamCampus.Colors.html#yellow_on_cyan_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_green/0","ref":"BeamCampus.Colors.html#yellow_on_green/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_green_blinking/0","ref":"BeamCampus.Colors.html#yellow_on_green_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_magenta/0","ref":"BeamCampus.Colors.html#yellow_on_magenta/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_magenta_blinking/0","ref":"BeamCampus.Colors.html#yellow_on_magenta_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_red/0","ref":"BeamCampus.Colors.html#yellow_on_red/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_red_blinking/0","ref":"BeamCampus.Colors.html#yellow_on_red_blinking/0"},{"type":"function","doc":"","title":"BeamCampus.Colors.yellow_on_white/0","ref":"BeamCampus.Colors.html#yellow_on_white/0"},{"type":"module","doc":"ExESDB is a wrapper around the khepri library. \n  Its intention is to provide an interface to khepri,\n  with a focus on event sourcing.","title":"ExESDB","ref":"ExESDB.html"},{"type":"module","doc":"Aggregates events from an event stream using tagged rules:\n  GIVEN: an Event of roughly this format:\n   %{\n    event_id: \"1234567890\",\n    event_type: \"user.birthday_celebrated:v1\",\n    stream_id: \"celebrate-user-birthday-john\",\n    version: 1,\n    data: %{\n      name: \"John\",\n      age: {:sum, 1},\n      venue: {:overwrite, \"New York\"}\n    },\n    timestamp: ~U[2022-01-01 12:00:00Z],\n    epoch: 1641013200,\n    metadata: %{\n      source_id: \"1234567890\"\n    }\n  }","title":"ExESDB.Aggregator","ref":"ExESDB.Aggregator.html"},{"type":"function","doc":"","title":"ExESDB.Aggregator.finalize_map/1","ref":"ExESDB.Aggregator.html#finalize_map/1"},{"type":"function","doc":"Folds a list of events into a single map.","title":"ExESDB.Aggregator.foldl/2","ref":"ExESDB.Aggregator.html#foldl/2"},{"type":"module","doc":"This module is used to start the ExESDB system.","title":"ExESDB.App","ref":"ExESDB.App.html"},{"type":"function","doc":"","title":"ExESDB.App.handle_info/2","ref":"ExESDB.App.html#handle_info/2"},{"type":"module","doc":"An adapter for Commanded to use ExESDB as the event store.\n  for reference, see: https://hexdocs.pm/commanded/Commanded.EventStore.Adapter.html","title":"ExESDB.Commanded.Adapter","ref":"ExESDB.Commanded.Adapter.html"},{"type":"type","doc":"","title":"ExESDB.Commanded.Adapter.adapter_meta/0","ref":"ExESDB.Commanded.Adapter.html#t:adapter_meta/0"},{"type":"function","doc":"Append one or more events to a stream atomically.","title":"ExESDB.Commanded.Adapter.append_to_stream/5","ref":"ExESDB.Commanded.Adapter.html#append_to_stream/5"},{"type":"type","doc":"","title":"ExESDB.Commanded.Adapter.application/0","ref":"ExESDB.Commanded.Adapter.html#t:application/0"},{"type":"function","doc":"Return a child spec defining all processes required by the event store.","title":"ExESDB.Commanded.Adapter.child_spec/2","ref":"ExESDB.Commanded.Adapter.html#child_spec/2"},{"type":"type","doc":"","title":"ExESDB.Commanded.Adapter.config/0","ref":"ExESDB.Commanded.Adapter.html#t:config/0"},{"type":"type","doc":"","title":"ExESDB.Commanded.Adapter.error/0","ref":"ExESDB.Commanded.Adapter.html#t:error/0"},{"type":"type","doc":"","title":"ExESDB.Commanded.Adapter.expected_version/0","ref":"ExESDB.Commanded.Adapter.html#t:expected_version/0"},{"type":"type","doc":"","title":"ExESDB.Commanded.Adapter.source_uuid/0","ref":"ExESDB.Commanded.Adapter.html#t:source_uuid/0"},{"type":"type","doc":"","title":"ExESDB.Commanded.Adapter.start_from/0","ref":"ExESDB.Commanded.Adapter.html#t:start_from/0"},{"type":"function","doc":"Streams events from the given stream, in the order in which they were\n  originally written.","title":"ExESDB.Commanded.Adapter.stream_forward/4","ref":"ExESDB.Commanded.Adapter.html#stream_forward/4"},{"type":"type","doc":"","title":"ExESDB.Commanded.Adapter.stream_uuid/0","ref":"ExESDB.Commanded.Adapter.html#t:stream_uuid/0"},{"type":"type","doc":"","title":"ExESDB.Commanded.Adapter.subscriber/0","ref":"ExESDB.Commanded.Adapter.html#t:subscriber/0"},{"type":"type","doc":"","title":"ExESDB.Commanded.Adapter.subscription/0","ref":"ExESDB.Commanded.Adapter.html#t:subscription/0"},{"type":"type","doc":"","title":"ExESDB.Commanded.Adapter.subscription_name/0","ref":"ExESDB.Commanded.Adapter.html#t:subscription_name/0"},{"type":"module","doc":"A mapper for Commanded to use ExESDB as the event store.","title":"ExESDB.Commanded.Mapper","ref":"ExESDB.Commanded.Mapper.html"},{"type":"function","doc":"Converts a Commanded EventData struct to an ExESDB NewEvent struct.\n  \n  Example:\n  iex> event_data = %Commanded.EventStore.EventData{\n  ...>   event_type: \"OrderPlaced\",\n  ...>   data: %{order_id: \"123\", customer_id: \"456\"},\n  ...>   metadata: %{correlation_id: \"123\", causation_id: \"456\"},\n  ...>   correlation_id: \"123\",\n  ...>   causation_id: \"456\"\n  ...> }\n  iex> event_id = UUIDv7.generate()\n  iex> ExESDB.Mapper.to_new_event(event_data)\n  %NewEvent{\n    event_id: ^event_id,\n    event_type: \"OrderPlaced\",\n    data_content_type: 1,\n    metadata_content_type: 1,\n    data: %{order_id: \"123\", customer_id: \"456\"},\n    metadata: %{\n      correlation_id: \"123\",\n      causation_id: \"456\"\n      stream_version: 0\n    }\n  }","title":"ExESDB.Commanded.Mapper.to_new_event/1","ref":"ExESDB.Commanded.Mapper.html#to_new_event/1"},{"type":"function","doc":"Converts an ExESDB EventRecord struct to a Commanded RecordedEvent struct.\n\n  Example:\n  iex> event_stream_id = \"stream-1\"\n  ^event_stream_id\n  iex> event_id = UUIDv7.generate()\n  ^event_id\n  iex> created = DateTime.utc_now()\n  ^created\n  iex> created_epoch = DateTime.to_unix(created, :millisecond)\n  ^created_epoch\n  iex> event_record = %EventRecord{\n  ...>   event_stream_id: \"stream-1\",\n  ...>   event_number: 1,\n  ...>   event_id: ^event_id,\n  ...>   event_type: \"OrderPlaced\",\n  ...>   data_content_type: 1,\n  ...>   metadata_content_type: 1,\n  ...>   data: %{order_id: \"123\", customer_id: \"456\"},\n  ...>   metadata: %{\n  ...>     correlation_id: \"123\",\n  ...>     causation_id: \"456\",\n  ...>     stream_version: 0\n  ...>   },\n  ...>   created: ^created,\n  ...>   created_epoch: ^created_epoch\n  ...> }\n  ^event_record\n  iex> ExESDB.Mapper.to_recorded_event(event_record)\n  %RecordedEvent{\n    event_id: ^event_id,\n    event_number: 1,\n    event_type: \"OrderPlaced\",\n    data: %{\n      order_id: \"123\", \n      customer_id: \"456\"\n    },\n    metadata: %{\n      correlation_id: \"123\",\n      causation_id: \"456\",\n      stream_version: 0\n    },\n    created_at: ^created,\n    stream_id: \"stream-1\",\n    stream_version: 0,\n    correlation_id: \"123\",\n    causation_id: \"456\"\n  }","title":"ExESDB.Commanded.Mapper.to_recorded_event/1","ref":"ExESDB.Commanded.Mapper.html#to_recorded_event/1"},{"type":"module","doc":"This module contains the environment variables that are used by ExESDB","title":"ExESDB.EnVars","ref":"ExESDB.EnVars.html"},{"type":"function","doc":"Returns the data directory. default: `/data`","title":"ExESDB.EnVars.data_dir/0","ref":"ExESDB.EnVars.html#data_dir/0"},{"type":"function","doc":"Returns the db type. `single` or `cluster`. default: `single`","title":"ExESDB.EnVars.db_type/0","ref":"ExESDB.EnVars.html#db_type/0"},{"type":"function","doc":"Returns the name of the pub/sub. default: `ex_esdb_pub_sub`","title":"ExESDB.EnVars.pub_sub/0","ref":"ExESDB.EnVars.html#pub_sub/0"},{"type":"function","doc":"Returns the seed nodes. default: `nil`","title":"ExESDB.EnVars.seed_nodes/0","ref":"ExESDB.EnVars.html#seed_nodes/0"},{"type":"function","doc":"Returns the khepri store id. default: `ex_esdb_store`","title":"ExESDB.EnVars.store_id/0","ref":"ExESDB.EnVars.html#store_id/0"},{"type":"function","doc":"Returns the timeout in milliseconds. default: `10_000`","title":"ExESDB.EnVars.timeout/0","ref":"ExESDB.EnVars.html#timeout/0"},{"type":"module","doc":"This module contains the event projector functionality","title":"ExESDB.EventProjector","ref":"ExESDB.EventProjector.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"ExESDB.EventProjector.child_spec/1","ref":"ExESDB.EventProjector.html#child_spec/1"},{"type":"function","doc":"","title":"ExESDB.EventProjector.start_link/1","ref":"ExESDB.EventProjector.html#start_link/1"},{"type":"module","doc":"A GenServer wrapper around :khepri to act as an event store.\nInspired by EventStoreDB's API.","title":"ExESDB.EventStore","ref":"ExESDB.EventStore.html"},{"type":"function","doc":"Append events to a stream.","title":"ExESDB.EventStore.append_to_stream/4","ref":"ExESDB.EventStore.html#append_to_stream/4"},{"type":"function","doc":"- `stream_id`: The id of the stream to append to.\n  - `expected_version`: The expected version of the stream (for optimistic concurrency).\n  - `events`: A list of events to append.","title":"Parameters - ExESDB.EventStore.append_to_stream/4","ref":"ExESDB.EventStore.html#append_to_stream/4-parameters"},{"type":"function","doc":"- `{:ok, new_stream_version}` if successful.\n  - `{:error, reason}` if unsuccessful.","title":"Returns - ExESDB.EventStore.append_to_stream/4","ref":"ExESDB.EventStore.html#append_to_stream/4-returns"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"ExESDB.EventStore.child_spec/1","ref":"ExESDB.EventStore.html#child_spec/1"},{"type":"function","doc":"Get the current state of the store.","title":"ExESDB.EventStore.get_state/1","ref":"ExESDB.EventStore.html#get_state/1"},{"type":"function","doc":"- `store`: The store to get the state of.","title":"Parameters - ExESDB.EventStore.get_state/1","ref":"ExESDB.EventStore.html#get_state/1-parameters"},{"type":"function","doc":"- `{:ok, state}`  if successful.\n    - `{:error, reason}` if unsuccessful.","title":"Returns - ExESDB.EventStore.get_state/1","ref":"ExESDB.EventStore.html#get_state/1-returns"},{"type":"function","doc":"Get the list of streams in the store.","title":"ExESDB.EventStore.get_streams/1","ref":"ExESDB.EventStore.html#get_streams/1"},{"type":"function","doc":"- `store`: The store to get the streams from.","title":"Parameters - ExESDB.EventStore.get_streams/1","ref":"ExESDB.EventStore.html#get_streams/1-parameters"},{"type":"function","doc":"- `{:ok, streams}`  if successful.","title":"Returns - ExESDB.EventStore.get_streams/1","ref":"ExESDB.EventStore.html#get_streams/1-returns"},{"type":"function","doc":"Read events from a stream.","title":"ExESDB.EventStore.read_stream_forward/4","ref":"ExESDB.EventStore.html#read_stream_forward/4"},{"type":"function","doc":"- `stream_name`: The name of the stream to read from.\n  - `start_version`: The version to start reading from.\n  - `count`: The number of events to read.","title":"Parameters - ExESDB.EventStore.read_stream_forward/4","ref":"ExESDB.EventStore.html#read_stream_forward/4-parameters"},{"type":"function","doc":"- `{:ok, events}` if successful.\n  - `{:error, reason}` if unsuccessful.","title":"Returns - ExESDB.EventStore.read_stream_forward/4","ref":"ExESDB.EventStore.html#read_stream_forward/4-returns"},{"type":"function","doc":"","title":"ExESDB.EventStore.start_link/1","ref":"ExESDB.EventStore.html#start_link/1"},{"type":"module","doc":"Messages are based on official proto file","title":"ExESDB.Messages","ref":"ExESDB.Messages.html"},{"type":"type","doc":"","title":"ExESDB.Messages.t/0","ref":"ExESDB.Messages.html#t:t/0"},{"type":"module","doc":"This module contains the options helper functions for ExESDB","title":"ExESDB.Options","ref":"ExESDB.Options.html"},{"type":"function","doc":"","title":"ExESDB.Options.app_env/0","ref":"ExESDB.Options.html#app_env/0"},{"type":"function","doc":"","title":"ExESDB.Options.app_env/1","ref":"ExESDB.Options.html#app_env/1"},{"type":"function","doc":"","title":"ExESDB.Options.data_dir/0","ref":"ExESDB.Options.html#data_dir/0"},{"type":"function","doc":"","title":"ExESDB.Options.db_type/0","ref":"ExESDB.Options.html#db_type/0"},{"type":"function","doc":"","title":"ExESDB.Options.pub_sub/0","ref":"ExESDB.Options.html#pub_sub/0"},{"type":"function","doc":"","title":"ExESDB.Options.seed_nodes/0","ref":"ExESDB.Options.html#seed_nodes/0"},{"type":"function","doc":"","title":"ExESDB.Options.store_id/0","ref":"ExESDB.Options.html#store_id/0"},{"type":"function","doc":"","title":"ExESDB.Options.sys_env/1","ref":"ExESDB.Options.html#sys_env/1"},{"type":"function","doc":"","title":"ExESDB.Options.timeout/0","ref":"ExESDB.Options.html#timeout/0"},{"type":"module","doc":"This module is to interact with the ExESDB.system, \n  running a store called \"reg_gh\" (Regulate Greenhouse)","title":"ExESDB.Repl","ref":"ExESDB.Repl.html"},{"type":"function","doc":"","title":"ExESDB.Repl.all/1","ref":"ExESDB.Repl.html#all/1"},{"type":"function","doc":"","title":"ExESDB.Repl.append/2","ref":"ExESDB.Repl.html#append/2"},{"type":"function","doc":"","title":"ExESDB.Repl.get_opts/0","ref":"ExESDB.Repl.html#get_opts/0"},{"type":"function","doc":"","title":"ExESDB.Repl.get_streams/0","ref":"ExESDB.Repl.html#get_streams/0"},{"type":"function","doc":"","title":"ExESDB.Repl.start_monitor/0","ref":"ExESDB.Repl.html#start_monitor/0"},{"type":"function","doc":"","title":"ExESDB.Repl.start_system/0","ref":"ExESDB.Repl.html#start_system/0"},{"type":"function","doc":"","title":"ExESDB.Repl.store/0","ref":"ExESDB.Repl.html#store/0"},{"type":"function","doc":"","title":"ExESDB.Repl.stream1/0","ref":"ExESDB.Repl.html#stream1/0"},{"type":"function","doc":"","title":"ExESDB.Repl.stream2/0","ref":"ExESDB.Repl.html#stream2/0"},{"type":"function","doc":"","title":"ExESDB.Repl.stream3/0","ref":"ExESDB.Repl.html#stream3/0"},{"type":"function","doc":"","title":"ExESDB.Repl.stream4/0","ref":"ExESDB.Repl.html#stream4/0"},{"type":"function","doc":"","title":"ExESDB.Repl.stream5/0","ref":"ExESDB.Repl.html#stream5/0"},{"type":"module","doc":"This module provides functions to get information about the EXESDB event store.","title":"ExESDB.StoreInfo","ref":"ExESDB.StoreInfo.html"},{"type":"function","doc":"Returns the list of streams in the store.","title":"ExESDB.StoreInfo.get_streams!/1","ref":"ExESDB.StoreInfo.html#get_streams!/1"},{"type":"function","doc":"","title":"ExESDB.StoreInfo.get_streams_raw/1","ref":"ExESDB.StoreInfo.html#get_streams_raw/1"},{"type":"function","doc":"Returns the version of the stream.","title":"ExESDB.StoreInfo.get_version!/2","ref":"ExESDB.StoreInfo.html#get_version!/2"},{"type":"module","doc":"Provides functions for working with event store subscriptions.","title":"ExESDB.Subscriptions","ref":"ExESDB.Subscriptions.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"ExESDB.Subscriptions.child_spec/1","ref":"ExESDB.Subscriptions.html#child_spec/1"},{"type":"function","doc":"","title":"ExESDB.Subscriptions.start_link/1","ref":"ExESDB.Subscriptions.html#start_link/1"},{"type":"function","doc":"","title":"ExESDB.Subscriptions.subscribe_to/6","ref":"ExESDB.Subscriptions.html#subscribe_to/6"},{"type":"function","doc":"","title":"ExESDB.Subscriptions.unsubscribe/2","ref":"ExESDB.Subscriptions.html#unsubscribe/2"},{"type":"module","doc":"This module is the top level supervisor for the ExESDB system.\n  It is responsible for supervising:\n  - the event store\n  - the cluster\n  - the Event Enitter (pub/sub)","title":"ExESDB.System","ref":"ExESDB.System.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"ExESDB.System.child_spec/1","ref":"ExESDB.System.html#child_spec/1"},{"type":"function","doc":"","title":"ExESDB.System.start/1","ref":"ExESDB.System.html#start/1"},{"type":"function","doc":"","title":"ExESDB.System.start_link/1","ref":"ExESDB.System.html#start_link/1"},{"type":"extras","doc":"# Architecture Decision Records","title":"Architecture Decision Records","ref":"adr.html"},{"type":"extras","doc":"","title":"2025.04.13 - Architecture Decision Records","ref":"adr.html#2025-04-13"},{"type":"extras","doc":"- `:streams` will be used to store the events that are being read from and written to the store.\n- `:subscriptions` will be used to store the subscription information of so-called `Persistent Subscriptions`.\n- `:projections` can best be thought of as stored procedures that are used to transform the events in the `Streams` into a different format or to enrich the streams with secondary or derived events, to name a few possible use cases.\n\nThus:\n\n```mono\n:khepri\n  |\n  +-:manage_orders\n      |\n      +-:streams\n      |\n      +-:subscriptions\n      |\n      +-:projections\n```","title":"Each Store will contain separate branches for Streams, Subscriptions, and Projections - Architecture Decision Records","ref":"adr.html#each-store-will-contain-separate-branches-for-streams-subscriptions-and-projections"},{"type":"extras","doc":"# Changelog","title":"Changelog","ref":"changelog.html"},{"type":"extras","doc":"","title":"version 0.0.8-alpha - Changelog","ref":"changelog.html#version-0-0-8-alpha"},{"type":"extras","doc":"- Added `ExESDB.EventStore.stream_forward/4` function\n- Added `BeamCampus.ColorFuncs` module\n- Added `ExESDB.Commanded.Adapter` module\n- Refactored `ExESDB.EventStreamReader` and `ExESDB.EventStreamWriter` modules:\n  Streams are now read and written using the `ExESDB.Streams` module","title":"2025.04.13 - Changelog","ref":"changelog.html#2025-04-13"},{"type":"extras","doc":"","title":"version 0.0.1-alpha - Changelog","ref":"changelog.html#version-0-0-1-alpha"},{"type":"extras","doc":"- Initial release","title":"2025.03.25 - Changelog","ref":"changelog.html#2025-03-25"},{"type":"extras","doc":"# Getting Started with ExESDB","title":"Getting Started","ref":"getting-started.html"},{"type":"extras","doc":"Event Sourcing with CQRS is a technique for building applications that are based on an immutable log of events, which makes it ideal for building concurrent, distributed systems.\n\nThough it is gaining popularity, the number of options for storing these events is limited and require specialized services like Kurrent (aka Greg's EventStore) or AxonIQ.\n\nOne of the strong-points of the BEAM is, that it comes 'batteries included': there are BEAM-native libraries for many common tasks, like: storage, pub/sub, caching, logging, telemetry, etc.\n\n`ExESDB` is an attempt to create a BEAM-native Event Store written in Elixir, building further upon the [Khepri](https://github.com/rabbitmq/khepri) library, which in turn builds upon the [Ra](https://github.com/rabbitmq/ra) library.","title":"Introduction - Getting Started","ref":"getting-started.html#introduction"},{"type":"extras","doc":"**This is a work in progress**\n\nThe project is in an early stage of development, and is not ready for production use.\n\nSource code is available on [GitHub](https://github.com/beam-campus/ex-esdb).","title":"Status - Getting Started","ref":"getting-started.html#status"},{"type":"extras","doc":"In your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:ex_esdb, \"~> 0.0.8-alpha\"}\n  ]\nend\n```","title":"Installation - Getting Started","ref":"getting-started.html#installation"},{"type":"extras","doc":"1. in your `config/config.exs` file:\n\n```elixir\nconfig :ex_esdb, :khepri,\n  # the directory where the khepri store will be created\n  data_dir: \"/data\",\n  # the id of the khepri store.\n  store_id: :ex_esdb_store,\n  # the type of database setup to use\n  db_type: :single,\n  # a global timeout in milliseconds\n  timeout: 10_000,\n  # a list of seed nodes to connect to\n  seed_nodes: [],\n  # the name of the pub/sub module to use\n  pub_sub: :ex_esdb_pub_sub\n\n```\n\n2. from the ENVIRONMENT:\n\n```bash\n\nEX_ESDB_DATA_DIR=\"/data\"\nEX_ESDB_STORE_ID=ex_esdb_store\nEX_ESDB_DB_TYPE=single\nEX_ESDB_TIMEOUT=10000\nEX_ESDB_SEED_NODES=\"\"\nEX_ESDB_PUB_SUB=ex_esdb_pub_sub\n\n```","title":"Configuration - Getting Started","ref":"getting-started.html#configuration"},{"type":"extras","doc":"```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  @impl true\n  def start(_type, _args) do\n    opts = ExESDB.Options.app_env()\n    children = [\n      {ExESDB.System, opts},\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n\nend\n```","title":"Usage - Getting Started","ref":"getting-started.html#usage"},{"type":"extras","doc":"","title":"Testing","ref":"testing.html"},{"type":"extras","doc":"# ExESDB - A BEAM-native Event Store\n\n`ExESDB` is a BEAM-native Event Store, built on top of the [khepri](https://github.com/rabbitmq/khepri) and [ra](https://github.com/rabbitmq/ra) subsystems.","title":"Read Me","ref":"readme.html"},{"type":"extras","doc":"One of the arguments for BEAM development is that it comes \"batteries included\". Be it caching, storage, pub/sub, observability etc... the Erlang ecosystem always has the option to avoid external dependencies.\n\nFor Event Sourcing use cases however, the Event Store is often a separate service.\n\nThis project is attempt at addressing this point, by building further upon the work of the `rabbitmq/khepri` and `rabbitmq/ra` subsystems.","title":"Motivation - Read Me","ref":"readme.html#motivation"},{"type":"extras","doc":"- [Getting Started](system/guides/getting_started.md)","title":"Contents - Read Me","ref":"readme.html#contents"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}